TChannel for Python
===================

|build-status| |coverage| |docs| |pypi|

A Python implementation of `TChannel`_.

`Documentation`_ is available on Read the Docs.

.. _TChannel: https://github.com/uber/tchannel

.. _Documentation: http://tchannel-python.readthedocs.org/en/latest/

.. |build-status| image:: https://travis-ci.org/uber/tchannel-python.svg?branch=master
    :target: https://travis-ci.org/uber/tchannel-python

.. |coverage| image:: https://coveralls.io/repos/uber/tchannel-python/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/uber/tchannel-python?branch=master

.. |docs| image:: https://readthedocs.org/projects/tchannel-python/badge/?version=latest
    :target: http://tchannel-python.readthedocs.org/en/latest/

.. |pypi| image:: https://badge.fury.io/py/tchannel.svg
    :target: http://badge.fury.io/py/tchannel
